OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системная метка «%1$s» создана",
    "Added system tag {systemtag}" : "Создана системная метка «{systemtag}»",
    "Added system tag %1$s" : "Создана системная метка «%1$s»",
    "%1$s added system tag %2$s" : "%1$sсоздал(а) системную метку «%2$s»",
    "{actor} added system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "System tag %1$s removed by the system" : "Системная метка «%1$s» удалена",
    "Removed system tag {systemtag}" : "Удалена системная метка «{systemtag}»",
    "Removed system tag %1$s" : "Удалена системная метка «%1$s»",
    "%1$s removed system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} removed system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You created system tag %1$s" : "Вы создали системную метку «%1$s»",
    "You created system tag {systemtag}" : "Вы создали системную метку «{systemtag}»",
    "%1$s created system tag %2$s" : "%1$s создал(а) системную метку «%2$s»",
    "{actor} created system tag {systemtag}" : "{actor} создал(а) системную метку «{systemtag}»",
    "You deleted system tag %1$s" : "Вы удалили системную метку «%1$s»",
    "You deleted system tag {systemtag}" : "Вы удалили системную метку «{systemtag}»",
    "%1$s deleted system tag %2$s" : "%1$s удалил(а) системную метку «%2$s»",
    "{actor} deleted system tag {systemtag}" : "{actor} удалил(а) системную метку «{systemtag}»",
    "You updated system tag %2$s to %1$s" : "Вы изменили системную метку «%2$s» на «%1$s»",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Вы изменили системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "%1$s updated system tag %3$s to %2$s" : "%1$s изменил(а) системную метку «%3$s» на «%2$s»",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} изменил(а) системную метку «{oldsystemtag}» на «{newsystemtag}»",
    "System tag %2$s was added to %1$s by the system" : "«%1$s» помечен системной меткой «%2$s»",
    "System tag {systemtag} was added to {file} by the system" : "«{file}» помечен системной меткой «{systemtag}»",
    "You added system tag %2$s to %1$s" : "Вы пометили «%1$s» системной меткой «%2$s»",
    "You added system tag {systemtag} to {file}" : "Вы пометили «{file}» системной меткой «{systemtag}» ",
    "%1$s added system tag %3$s to %2$s" : "%1$s пометил(а) «%2$s» системной меткой «%3$s» ",
    "{actor} added system tag {systemtag} to {file}" : "{actor} пометил(а) «{file}» системной меткой «{systemtag}»",
    "System tag %2$s was removed from %1$s by the system" : "Системная метка «%2$s» убрана с «%1$s»",
    "System tag {systemtag} was removed from {file} by the system" : "Системная метка «{systemtag}» убрана с «{file}»",
    "You removed system tag %2$s from %1$s" : "Вы убрали системную метку «%2$s»  с «%1$s»",
    "You removed system tag {systemtag} from {file}" : "Вы убрали системную метку «{systemtag}» с «{file}»",
    "%1$s removed system tag %3$s from %2$s" : "%1$s убрал(а) системную метку «%3$s» с «%2$s»",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} убрал(а) системную метку «{systemtag}» с «{file}»",
    "%s (restricted)" : "%s (ограниченная)",
    "%s (invisible)" : "%s (невидимая)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системные метки</strong> файла были изменены",
    "Tags" : "Метки",
    "All tagged %s …" : "Все помеченные %s ...",
    "tagged %s" : "помеченные %s",
    "Collaborative tags" : "Метки совместной работы",
    "Collaborative tagging functionality which shares tags among people." : "Функционал совместных меток, который публикует метки среди пользователей.",
    "Create or edit tags" : "Создание или изменение меток",
    "Search for a tag to edit" : "Поиск метки для изменения",
    "Collaborative tags …" : "Совместные теги ...",
    "No tags to select" : "Нет меток для выбора",
    "Tag name" : "Название метки",
    "Tag level" : "Уровень тега",
    "Create" : "Создать",
    "Update" : "Обновить",
    "Delete" : "Удалить",
    "Reset" : "Сбросить",
    "Loading …" : "Загрузка…",
    "Public" : "Общая",
    "Restricted" : "Ограниченная",
    "Invisible" : "Невидимая",
    "Created tag" : "Метка создана",
    "Failed to create tag" : "Не удалось создать тег",
    "Updated tag" : "Метка обновлена",
    "Failed to update tag" : "Не удалось обновить метку",
    "Deleted tag" : "Метка удалена",
    "Failed to delete tag" : "Не удалось удалить тег",
    "Loading collaborative tags …" : "Загрузка совместных тегов ...",
    "Search or create collaborative tags" : "Поиск или создание совместных тегов",
    "No tags to select, type to create a new tag" : "Нет тегов для выбора. Введите что-нибудь для создания нового тега",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load selected tags" : "Не удалось загрузить выбранный тег",
    "Failed to select tag" : "Не удалось выбрать тег",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные теги доступны для всех пользователей. Ограниченные теги видны пользователям, но не могут быть назначены ими. Невидимые теги предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
    "This file has the tag {tag}" : "У этого файла есть тэг: {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "У этого файла есть тэги: {firstTags} и {lastTag}",
    "List of tags and their associated files and folders." : "Список тегов и связанных с ними файлов и папок.",
    "No tags found" : "Меток не найдено",
    "Tags you have created will show up here." : "Здесь будут отображаться созданные вами теги.",
    "Failed to load last used tags" : "Не удалось загрузить последние использованные метки",
    "Missing \"Content-Location\" header" : "Отсутствует заголовок «Content-Location»",
    "Failed to load tags for file" : "Не удалось загрузить метки для файла",
    "Failed to set tag for file" : "Не удалось поставить метку файлу",
    "Failed to delete tag for file" : "Не удалось удалить метку у файла",
    "Tag name is empty" : "Имя метки пусто",
    "Select tag …" : "Выберите метку…",
    "Collaborative tagging functionality which shares tags among users." : "Совместная работа с метками файлов.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Совместная работа с метками файлов, предназначенная для групп пользователей. (Провайдерам с большим количеством клиентов рекомендуется отключить это приложение, так как метки являются общими).",
    "Tagged files" : "Помеченные файлы",
    "Select tags to filter by" : "Выберите метки для отбора",
    "Please select tags to filter by" : "Выберите метки для отбора",
    "No files found for the selected tags" : "Не найдено файлов с выбранными метками",
    "Create a new tag" : "Создать метку",
    "Name" : "Имя",
    "No files in here" : "Здесь нет файлов",
    "No entries found in this folder" : "В этой папке не найдено ни одной записи",
    "Size" : "Размер",
    "Modified" : "Изменён"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
